==> haskell-base16-bytestring-0.1.1.6-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base16-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base16-bytestring
version: 0.1.1.6
id: base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
key: base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
license: BSD-3-Clause
copyright: 2010 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://github.com/bos/base16-bytestring
synopsis: Fast base16 (hex) encoding and decoding for ByteStrings
description:
    Fast base16 (hex) encoding and decoding for ByteStrings
category: Data
abi: 39dfe9068523cd9f792b1a7393cda8b3
exposed: True
exposed-modules:
    Data.ByteString.Base16 Data.ByteString.Base16.Lazy
import-dirs: /usr/lib/ghc-8.4.2/site-local/base16-bytestring-0.1.1.6
library-dirs: /usr/lib/ghc-8.4.2/site-local/base16-bytestring-0.1.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/base16-bytestring-0.1.1.6
hs-libraries: HSbase16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
depends:
    base-4.11.1.0 bytestring-0.10.8.2 ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             ghc-prim-0.5.2.0=a22477c99003a90dd639dbfd07997615
haddock-interfaces: /usr/share/doc/haskell-base16-bytestring/html/base16-bytestring.haddock
haddock-html: /usr/share/doc/haskell-base16-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base16-bytestring-0.1.1.6-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base16-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base16-bytestring
version: 0.1.1.6
id: base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
key: base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
license: BSD-3-Clause
copyright: 2010 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://github.com/bos/base16-bytestring
synopsis: Fast base16 (hex) encoding and decoding for ByteStrings
description:
    Fast base16 (hex) encoding and decoding for ByteStrings
category: Data
abi: 8e8bf906de482980844f4b69dcf0e9fe
exposed: True
exposed-modules:
    Data.ByteString.Base16 Data.ByteString.Base16.Lazy
import-dirs: /usr/lib/ghc-8.6.1/site-local/base16-bytestring-0.1.1.6
library-dirs: /usr/lib/ghc-8.6.1/site-local/base16-bytestring-0.1.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/base16-bytestring-0.1.1.6
hs-libraries: HSbase16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
depends:
    base-4.12.0.0 bytestring-0.10.8.2 ghc-prim-0.5.3
haddock-interfaces: /usr/share/doc/haskell-base16-bytestring/html/base16-bytestring.haddock
haddock-html: /usr/share/doc/haskell-base16-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
